summaryrefslogtreecommitdiff
path: root/src/command_type.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/command_type.h')
-rw-r--r--src/command_type.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/command_type.h b/src/command_type.h
index 1a48f287a..0bff05003 100644
--- a/src/command_type.h
+++ b/src/command_type.h
@@ -392,13 +392,13 @@ struct Command {
* are from the #CommandProc callback type. The boolean parameter indicates if the
* command succeeded or failed.
*
* @param success If the command succeeded or not.
* @param tile The tile of the command action
* @param p1 Additional data of the command
* @param p1 Additional data of the command
* @see CommandProc
*/
-typedef void CommandCallback(bool success, TileIndex tile, uint32 p1, uint32 p2);
+typedef void CommandCallback(const CommandCost &result, TileIndex tile, uint32 p1, uint32 p2);
/**
* Structure for buffering the build command when selecting a station to join.
@@ -392,13 +392,13 @@ struct Command {
* command succeeded or failed.
*
- * @param success If the command succeeded or not.
+ * @param result The result of the executed command
* @param tile The tile of the command action
* @param p1 Additional data of the command